#
# spec file for package dracut-saltboot
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dracut-saltboot
Version:        0.1.1750754284.36c722f
Release:        150000.1.59.1
Source:         dracut-saltboot-%{version}.tar.xz
Summary:        SALT-based PXE network boot dracut module
License:        GPL-2.0
Group:          System/Packages
BuildArch:      noarch
BuildRequires:  dracut
Requires:       dracut

# Requires for saltboot functionality
Requires:       bind-utils
Requires:       cryptsetup
Requires:       curl
Requires:       device-mapper
Requires:       e2fsprogs
Requires:       gzip
Requires:       parted
Requires:       xz
Recommends:     kiwi-tools

%description
dracut module for booting SALT-based PXE images.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/dracut/modules.d/50saltboot
cp -R saltboot/* %{buildroot}%{_prefix}/lib/dracut/modules.d/50saltboot
chmod 755 %{buildroot}%{_prefix}/lib/dracut/modules.d/50saltboot/*
install -D -m 644 -t %{buildroot}%{_unitdir}/ services/*

%files
%{_prefix}/lib/dracut/modules.d/50saltboot
%{_unitdir}/*

%pre
%service_add_pre image-deployed-bundle.service image-deployed.service install-local-bootloader.service migrate-to-bundle.service

%post
%service_add_post image-deployed-bundle.service image-deployed.service install-local-bootloader.service migrate-to-bundle.service

%preun
%service_del_preun image-deployed-bundle.service image-deployed.service install-local-bootloader.service migrate-to-bundle.service

%postun
%service_del_postun image-deployed-bundle.service image-deployed.service install-local-bootloader.service migrate-to-bundle.service

%changelog
* Thu Jun 19 2025 oholecek@suse.com
- Update to version 0.1.1750754284.36c722f
  * Add missing chroot dependency for bootloader installation
* Fri Oct 25 2024 oholecek@suse.com
- Update to version 0.1.1728559936.c16d4fb
  * Add MAC based terminal naming option (jsc#SUMA-314)
* Tue Mar 19 2024 oholecek@suse.com
- Update to version 0.1.1710765237.46af599
  * Load only first available leaseinfo (bsc#1221092)
* Wed Apr 19 2023 oholecek@suse.com
- Update to version 0.1.1681904360.84ef141
  * Load network configuration even when missing protocol version
    (bsc#1210640)
* Tue Feb 21 2023 oholecek@suse.com
- Update to verion 0.1.1674034019.a93ff61
  * Install copied wicked config as client.xml (bsc#1205599)
* Mon Jan  9 2023 oholecek@suse.com
- Update to version 0.1.1673279145.e7616bd
  * Add failsafe stop file when salt-minion does not stop (bsc#1172110)
  * Copy existing wicked config instead of generating new (bsc#1205599)
* Mon Nov  7 2022 oholecek@suse.com
- Update to version 0.1.1665997480.587fa10
  * Add dependencies on xz and gzip to support compressed images
* Fri Aug 26 2022 nadvornik@suse.com
- Update to version 0.1.1661440542.6cbe0da
  * Use standard susemanager.conf
  * Move image services to dracut-saltboot package
  * Use salt bundle
* Tue Aug 23 2022 nadvornik@suse.com
- Require e2fsprogs (bsc#1202614)
* Tue Jul 12 2022 oholecek@suse.com
- Update to version 0.1.1657643023.0d694ce
  * Update dracut-saltboot dependencies (bsc#1200970)
  * Fix network loading when ipappend is used in pxe config
  * Add new information messages
* Wed Aug  4 2021 nadvornik@suse.com
- Fix dependencies of python libs (bsc#1188846)
- Update to version 0.1.1628156312.dbd0dec
* Wed Jul 28 2021 nadvornik@suse.com
- Force installation of libexpat.so.1 (bsc#1188846)
- Update to version 0.1.1627546504.96a0b3e
* Fri May 28 2021 nadvornik@suse.com
- Use kernel parameters from PXE formula also for local boot
* Mon Feb  1 2021 nadvornik@suse.com
- Use saltboot/defaults file
- Update to version 0.1.1614159840.ef7cad5
* Wed Sep  9 2020 nadvornik@suse.com
- Support autosign grains in saltboot intrd
- Update to version 0.1.1602150122.f08af0a
* Fri Aug 14 2020 oholecek@suse.com
- Set wicked to use plain mac address for computing DHCP DUID
- Copy wicked lease xml file to prevent query for second IP address
  (bsc#1173268)
* Tue Jul 21 2020 nadvornik@suse.com
- Use automatic RAID assembly only in the first phase before
  start of salt
- Update to version 0.1.1595937550.0285244
* Tue May 12 2020 nadvornik@suse.com
- Print a list of available disk devices (bsc#1170824)
- Install wipefs to initrd
- Update to version 0.1.1590413773.a959db7
* Thu Apr 23 2020 nadvornik@suse.com
- Force install crypt modules
- Update to version 0.1.1588156049.952b58d
* Thu Apr  9 2020 oholecek@suse.com
- Add missing terminal naming modifiers as exported veriables
- Update to version 0.1.1587051918.6bc9e88
* Mon Mar 16 2020 nadvornik@suse.com
- Assemble existing RAIDs before searching for salt configuration
- Update to version 0.1.1585064259.12b97ef
* Wed Mar 11 2020 nadvornik@suse.com
- Force installation of raid1 kernel module
* Tue Mar 10 2020 nadvornik@suse.com
- Use more reliable progress output
* Sat Feb 29 2020 oholecek@suse.com
- Use start event grains to avoid extra grains calls
- Update to version 0.1.1583842676.2fc2fa6
* Wed Jan 29 2020 oholecek@suse.com
- Add support for FQDN as a terminal name
- Update to version 0.1.1580471316.1839544
* Thu Jan  9 2020 oholecek@suse.com
- Source wicked network information to access IPADDR and DNSDOMAIN variables
- Replace systemException functions by log and reboot actions
- Stop waiting for devices when dracut timeout is hit
- Update to version 0.1.1579102150.4716559
* Wed Nov 20 2019 oholecek@suse.com
- Include swapon in saltboot initrd
- Update to version 0.1.1574263639.c30ba46
* Mon Aug 19 2019 nadvornik@suse.com
- Updated for SLES15
- Update to version 0.1.1573133286.06608d5
* Tue Aug 13 2019 nadvornik@suse.com
- Copy saltboot.sh from kiwi-desc-saltboot
* Mon Nov 20 2017 nadvornik@suse.com
- new package
